# Changelog

## [0.6.0a1](https://github.com/OpenVoiceOS/ovos-utils/tree/0.6.0a1) (2024-12-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/0.5.6...0.6.0a1)

**Implemented enhancements:**

- feat: support \[optional\] syntax [\#312](https://github.com/OpenVoiceOS/ovos-utils/issues/312)

**Merged pull requests:**

- feat: extend dialog/intent templates [\#317](https://github.com/OpenVoiceOS/ovos-utils/pull/317) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
